@@ -17,7 +17,6 @@
  *************************************************************************************/
 
 #include <QApplication>
-#include <KAboutData>
 #include "kalgebra.h"
 #include <klocalizedstring.h>
 
@@ -25,7 +24,7 @@ int main(int argc, char *argv[])
 {
 	QApplication app(argc, argv);
 	app.setApplicationName("kalgebra");
-	app.setApplicationDisplayName(app.tr("KAlgebra"));
+	app.setApplicationDisplayName(i18n("KAlgebra"));
 	app.setApplicationVersion("0.99");
 	
         KLocalizedString::setApplicationDomain("kalgebra");
